--======================================================================
--= Title:			Gluttony										   =
--= Author:			Michael Kosler									   =
--= License:		see LICENSE.txt									   =
--= Description:	Eat and be fat!									   =
--= Version:		0.2												   =
--= Changes:		+ Rebuilt source code into a more organized manner =
--=					+ Added menus									   =
--=					+ Added small, text only tutorial				   =
--======================================================================

--- Required libraries/packages
local menuState = require "./states/menu.lua"
local playState = require "./states/play.lua"

SCREENSIZE = love.graphics.getWidth()	-- It is square window, so width = height

--- Loads the appropriate gameState
function love.load()
	isTut = true
	font = love.graphics.newFont(13)
	love.graphics.setFont(font)
	score = 0
	events = {}
	math.randomseed(os.time())
	currentState = "menu"
	menuState.load()
end

--- Updates the appropriate gameState
-- @param dt: delta time
function love.update(dt)
	local pos = {}
	pos.x, pos.y = love.mouse.getPosition()
	if currentState == "menu" then
		menuState.update(dt, pos)
	elseif currentState == "play" then
		playState.update(dt, pos)
	else
		error("bad state var: " .. currentState)
	end
	for k,v in pairs(events) do
		v()
		table.remove(events, k)
	end
end

--- Draws the appropriate gameState
function love.draw()
	if currentState == "menu" then
		local tempScore = "Score: " .. score
		menuState.draw()
		if not isTut then
			love.graphics.setColor(255,255,255,255)
			love.graphics.print(
				tempScore,
				(SCREENSIZE / 2) - (font:getWidth(tempScore) / 2),
				0)
		end
	elseif currentState == "play" then
		playState.draw()
	end
end

--======================================================================
-- RANDOM GLOBAL FUNCTIONS
--======================================================================

--- Clamps a value between two bounds
-- @param v: value to be clamped
-- @param min: lower bound
-- @param max: upper bound
function clamp(v, min, max)
	if v < min then return min
	elseif v > max then return max
	else return v end
end

--- Circle-to-circle collision testing
-- @param a: circle A
-- @param b: circle B
function collision(a, b)
	local dist = math.sqrt((a.x - b.x)^2 + (a.y - b.y)^2)
	if dist < (a.r + b.r) then return true
	else return false end
end

--- Toggles a boolean variable
-- @param a: boolean variable to be toggled
function toggle(a)
	if a == true then return false
	else return true end
end

--- Toggles various parameters in order to start a new game
function startGame()
	love.mouse.setVisible(false)
	currentState = "play"
	isTut = false
	playState.load()
end

--- Toggles various parameters in order to disply the retry button
function endGame()
	local function e()
		love.mouse.setVisible(true)
		currentState = "menu"
		for k,v in pairs(buttons) do
			if k == "retry" or k == "quit" then
				v.isVisible = true
			else
				v.isVisible = false
			end
		end
		for _,v in pairs(slides) do
			v.isVisible = false
		end
	end
	table.insert(events, e)
end
