--- Required libraries/packages
local colorsLib = require "../lib/colors.lua"

--- The button metatable
local button = {}
button.__index = button
button.__newindex = function() error("can't assign new var") end
button.__metatable = true

--- The button constructor
-- @param x: x-coordinate
-- @param y: y-coordinate
-- @param w: width
-- @param h: height
-- @param text: string to be written in the button
-- @param bgColor: button background color
-- @param textColor: button text color
-- @param e: event function to be called on mouse click
function createButton(x, y, w, h, text, bgColor, textColor, e)
	assert(type(text) == "string", "bad arg: text not string")
	assert(type(bgColor) == "string" or "table",
		"bad arg: bgColor not string or table")
	assert(type(textColor) == "string" or "table",
		"bad arg: textColor not string or table")
	assert(type(e) == "function", "bad arg: e not a function")
	local b = {
		x = x,
		y = y,
		w = w,
		h = h,
		text = {
			line = text,
			x = x + 5,
			y = y + 5,
			color = colorsLib.pickColor(textColor),
		},
		bgColor = colorsLib.pickColor(bgColor),
		e = e,
		isVisible = true,
	}
	return setmetatable(b, button)
end

--- Inserts the button event into the events table to be executed
function button:sendEvent()
	table.insert(events, self.e)
end

--- Checks for mouse clicks over the button
-- @param pos: mouse position
function button:update(pos)
	if not self.isVisible then return end
	if self.x <= pos.x and pos.x <= (self.x + self.w) then
		if self.y <= pos.y and pos.y <= (self.y + self.h) then
			function love.mousepressed(x, y, button)
				if button == "l" then
					self:sendEvent()
				end
			end
		end
	end
end

--- Draws the button
function button:draw()
	if not self.isVisible then return end
	love.graphics.setColor(
		self.bgColor.r,
		self.bgColor.g,
		self.bgColor.b,
		self.bgColor.a)
	love.graphics.rectangle(
		"fill",
		self.x,
		self.y,
		self.w,
		self.h)
	love.graphics.setColor(
		self.text.color.r,
		self.text.color.g,
		self.text.color.b,
		self.text.color.a)
	love.graphics.print(
		self.text.line,
		self.text.x,
		self.text.y)
end
