--- Required libraries/packages
local colorsLib = require "../lib/colors.lua"

--- The food metatable
local food = {}
food.__index = food
food.__newindex = function() error("can't assign new var") end
food.__metatable = true

--- CONSTANTS
local FOODSPAWNOFFSET = 20
local FOODRADIUS = 5

--- Generates a random position that is not underneath the player
-- @param pCir: the player circle
local function getRandPos(pCir)
	local x = math.random(FOODSPAWNOFFSET, SCREENSIZE - FOODSPAWNOFFSET)
	local y = math.random(FOODSPAWNOFFSET, SCREENSIZE - FOODSPAWNOFFSET)
	if collision(pCir,{x=x,y=y,r=FOODRADIUS}) then
		print("Spawned under player, getting new position")
		return getRandPos(pCir)
	else
		return x, y
	end
end

--- The food constructor
-- @param pCir: the player circle
function createFood(pCir)
	local x, y = getRandPos(pCir)
	local f = {
		x = x,
		y = y,
		r = FOODRADIUS,
	}
	f.color = {}
	if math.random() < 0.75 then
		f.color.name = "red"
	else
		f.color.name = "green"
	end
	t = colorsLib.pickColor(f.color.name)
	f.color.r = t.r
	f.color.g = t.g
	f.color.b = t.b
	f.color.a = t.a
	t = nil
	return setmetatable(f, food)
end

--- Draws the food
function food:draw()
	love.graphics.setColor(
		self.color.r,
		self.color.g,
		self.color.b,
		self.color.a)
	love.graphics.circle(
		"fill",
		self.x,
		self.y,
		self.r)
end
