--- Required libraries/packages
local colorsLib = require "../lib/colors.lua"

--- The slide metatable
local slide = {}
slide.__index = slide
slide.__newindex = function() error("can't assign new var") end
slide.__metatable = true

--- The slide constructor
-- @param x: x-coordinate
-- @param y: y-coordinate
-- @param w: width
-- @param h: height
-- @param text: string to be written in the slide
-- @param bgColor: slide background color
-- @param textColor: slide text color
function createSlide(x, y, w, h, text, bgColor, textColor)
	local offsetx = 5
	local offsety = 5
	assert(type(text) == "string", "bad arg: text not string")
	assert(type(bgColor) == "string" or "table",
		"bad arg: bgColor not string or table")
	assert(type(textColor) == "string" or "table",
		"bad arg: textColor not string or table")
	local s = {
		x = x,
		y = y,
		w = w,
		h = h,
		bgColor = colorsLib.pickColor(bgColor),
		isVisible = true,
	}
	if text ~= "" then
		s.text = {
			line = text,
			x = x + offsetx,
			y = y + offsety,
			limit = w - (offsetx * 2),
			color = colorsLib.pickColor(textColor),
		}
	end
	return setmetatable(s, slide)
end

-- Draws the slide
function slide:draw()
	if not self.isVisible then return end
	love.graphics.setColor(
		self.bgColor.r,
		self.bgColor.g,
		self.bgColor.b,
		self.bgColor.a)
	love.graphics.rectangle(
		"fill",
		self.x,
		self.y,
		self.w,
		self.h)
	love.graphics.setColor(
		self.text.color.r,
		self.text.color.g,
		self.text.color.b,
		self.text.color.a)
	love.graphics.printf(
		self.text.line,
		self.text.x,
		self.text.y,
		self.text.limit)
end
