do
	--- Required libraries/packages
	local buttonLib = require "./obj/button.lua"
	local slideLib = require "./obj/slide.lua"
	
	local _LOADCHECK = false
	
	--- Loads the menuState
	local function load()
		if _LOADCHECK then return end
		local BUTTONWIDTH = 50
		local BUTTONHEIGHT = 25
		local buttonBGColor = "white"
		local buttonTextColor = "black"
		local slideBGColor = "black"
		local slideTextColor = "white"
		slideIndex = 1
		numSlides = 0
		events = {}
		buttons = {}
		buttons.prev = createButton(
			10,
			SCREENSIZE - BUTTONHEIGHT - 10,
			BUTTONWIDTH,
			BUTTONHEIGHT,
			"PREV",
			buttonBGColor,
			buttonTextColor,
			function()
				if slideIndex > 1 then
					slideIndex = slideIndex - 1
				end
			end)
		buttons.next = createButton(
			buttons.prev.x + BUTTONWIDTH + 10,
			SCREENSIZE - BUTTONHEIGHT - 10,
			BUTTONWIDTH,
			BUTTONHEIGHT,
			"NEXT",
			buttonBGColor,
			buttonTextColor,
			function()
				if slideIndex < numSlides then
					slideIndex = slideIndex + 1
				end
			end)
		buttons.start = createButton(
			SCREENSIZE - ((BUTTONWIDTH + 10) * 2),
			SCREENSIZE - BUTTONHEIGHT - 10,
			BUTTONWIDTH,
			BUTTONHEIGHT,
			"START",
			buttonBGColor,
			buttonTextColor,
			startGame)
		buttons.retry = createButton(
			(SCREENSIZE / 2) - (BUTTONWIDTH / 2),
			(SCREENSIZE / 2) - (BUTTONHEIGHT / 2),
			BUTTONWIDTH,
			BUTTONHEIGHT,
			"RETRY",
			buttonBGColor,
			buttonTextColor,
			startGame)
		buttons.quit = createButton(
			SCREENSIZE - BUTTONWIDTH - 10,
			SCREENSIZE - BUTTONHEIGHT - 10,
			BUTTONWIDTH,
			BUTTONHEIGHT,
			"QUIT",
			buttonBGColor,
			buttonTextColor,
			function() love.event.push("q") end)
		slides = {}
		slides.tut1 = createSlide(
			0,
			0,
			SCREENSIZE,
			SCREENSIZE,
			"You are the white dot. You are late for work, but really hungry. Eat as much food as you can within five seconds.",
			slideBGColor,
			slideTextColor)
		slides.tut2 = createSlide(
			0,
			0,
			SCREENSIZE,
			SCREENSIZE,
			"Control your movement with the mouse. When you touch a piece of food. You eat it.",
			slideBGColor,
			slideTextColor)
		slides.tut3 = createSlide(
			0,
			0,
			SCREENSIZE,
			SCREENSIZE,
			"Good (green) food increases the amount of time you have to eat, but also makes you fatter.",
			slideBGColor,
			slideTextColor)
		slides.tut4 = createSlide(
			0,
			0,
			SCREENSIZE,
			SCREENSIZE,
			"Bad (red) good decreases the amount of time you have, but you immediately spit it out, so you don't get fatter.",
			slideBGColor,
			slideTextColor)
		for _,_ in pairs(slides) do
			numSlides = numSlides + 1
		end
		buttons.retry.isVisible = false
		_LOADCHECK = true
	end
	
	--- Updates the menuState
	-- @param dt: delta time
	-- @param pos: mouse position
	local function update(dt, pos)
		for _,v in pairs(buttons) do
			v:update(pos)
		end
		if slideIndex == 1 then
			buttons.prev.isVisible = false
		elseif slideIndex == numSlides then
			buttons.next.isVisible = false
		else
			buttons.next.isVisible = true
			buttons.prev.isVisible = true
		end
	end
	
	--- Draws the menuState
	local function draw()
		slides["tut" .. slideIndex]:draw()
		for k,v in pairs(buttons) do
			v:draw()
		end
	end
	
	--- The menuState namespace/package
	menu = {
		load = load,
		update = update,
		draw = draw,
	}
	
	return menu
end
